===============
``expressions``
===============

.. automodule:: tt.expressions


``expressions.bexpr`` module
----------------------------

.. automodule:: tt.expressions.bexpr
    :members:
    :exclude-members: __weakref__
